Author: Jean-Philippe Meuret
Keywords: distance, sampling, mcds, ACDC, Cournols, Olloix, 2019, Distance Sampling, Naturalist, smartphone, full

ACDC 2019 Naturalist
Analysis 28 : Details

## Results: main figures

Study type: Point transect, Radial distance, No clustering.

Units used: Meter for distances, Sq. Kilometer for areas.

Note: Most figures have been rounded for readability, but 'CoefVar Density' have been further modified : converted to %

| Echant | Espèce | Passage | Adulte | Durée | NTot Obs | Max Dist | Analyse | Mod Key Fn | Mod Adj Ser | Left Trunc Dist | Right Trunc Dist | Fit Dist Cuts | ExCod | Effort | NObs | Obs Rate | NumPars AdjSer | Delta AIC | Chi2 P | KS P | CvM Uw P | CvM Cw P | CoefVar Density | Qual Bal 3 | Qual Bal 2 | Qual Bal 1 | Qual Chi2+ | Qual KS+ | Qual DCv+ | Density | Min Density | Max Density | Number | Min Number | Max Number | EDR/ESW | Min EDR/ESW | Max EDR/ESW | PDetec | Min PDetec | Max PDetec | RunFolder
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
28 | 1 | Sylvia atricapilla | a+b | m | 10mn | 403 | 511.41 | 49 | HAZARD | POLY | 5 | 492 | 13 | 1 | 190 | 401 | 99.5 | 0 | 0 | 0.25 | 0.55 | 0.6 | 0.7 | 10 | 0.65 | 0.64 | 0.65 | 0.58 | 0.64 | 0.67 | 37.58 | 30.87 | 45.75 | 902 | 741 | 1098 | 133.7 | 124.4 | 143.6 | 0.074 | 0.064 | 0.085 | SylvAtri-ab-10mn-m-haz-pol-la-ra-ma-90vq_6nr

## Results: all details

Study type: Point transect, Radial distance, No clustering.

Units used: Meter for distances, Sq. Kilometer for areas.

Note: All values have been left untouched, as output by MCDS (no rounding, no conversion)

| Analyse | Echant | Espèce | Passage | Adulte | Durée | FonctionClé | SérieAjust | TrGche | TrDrte | NbTrchMod | Abrev. Analyse | OptimTrunc | NTot Obs | Min Dist | Max Dist | Mod Key Fn | Mod Adj Ser | Mod Chc Crit | Conf Interv | Left Trunc Dist | Right Trunc Dist | Fit Dist Cuts | ExCod | StartTime | ElapsedTime | RunFolder | NObs | NSamp | Effort | EncRate | CoefVar EncRate | Min EncRate | Max EncRate | DoF EncRate | Left Trunc | Right Trunc | Obs Rate | TotNum Pars | Delta AIC | AIC | Chi2 P | Chi2 P 1 | Chi2 P 2 | Chi2 P 3 | f/h(0) | CoefVar f/h(0) | Min f/h(0) | Max f/h(0) | DoF f/h(0) | PDetec | CoefVar PDetec | Min PDetec | Max PDetec | DoF PDetec | EDR/ESW | CoefVar EDR/ESW | Min EDR/ESW | Max EDR/ESW | DoF EDR/ESW | AICc | BIC | LogLhood | KS P | CvM Uw P | CvM Cw P | Key Fn | Adj Ser | NumPars KeyFn | NumPars AdjSer | Num Covars | EstA(1) | EstA(2) | EstA(3) | DensClu | CoefVar DensClu | Min DensClu | Max DensClu | DoF DensClu | Density | Delta CoefVar Density | CoefVar Density | Min Density | Max Density | DoF Density | Number | CoefVar Number | Min Number | Max Number | DoF Number | Qual Bal 1 | Qual Bal 2 | Qual Bal 3 | Qual Chi2+ | Qual KS+ | Qual DCv+ | Group Left Trunc | Group Right Trunc | Order Same Trunc AIC | Order Close Trunc Chi2 KS DCv | Order Close Trunc DCv | Order Close Trunc Bal 1 Qual | Order Close Trunc Bal 2 Qual | Order Close Trunc Bal 3 Qual | Order Close Trunc Bal Chi2+ Qual | Order Close Trunc Bal KS+ Qual | Order Close Trunc Bal DCv+ Qual | Order Global Chi2 KS DCv | Order Global Bal 1 Qual | Order Global Bal 2 Qual | Order Global Bal 3 Qual | Order Global Bal Chi2+ Qual | Order Global Bal KS+ Qual | Order Global Bal DCv+ Qual | Order Global DeltaAIC Chi2 KS DCv
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
28 | 49 | 1 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 4.553960 | 492.328316 | 13.000000 | SylvAtri-ab-10mn-m-haz-pol-la-ra-ma | 1 | 403 | 1.212094 | 511.409745 | HAZARD | POLY | AIC | 95 | 4.553960 | 492.328316 | 13.000000 | 1 | 2023-04-30 15:55:03.377000 | 1.300000 | SylvAtri-ab-10mn-m-haz-pol-la-ra-ma-90vq_6nr | 401 | 96 | 190 | 2.110526 | 0.068677 | 1.841824 | 2.418429 | 95 | 4.553960 | 492.328000 | 99.503722 | 2.000000 | 0.000000 | 4488.174000 | 0.250081 | 0.250081 | nan | nan | 0.000112 | 0.073005 | 0.000097 | 0.000129 | 399.000000 | 0.073743 | 0.073005 | 0.063896 | 0.085108 | 399.000000 | 133.695000 | 0.036502 | 124.440000 | 143.638200 | 399.000000 | 4488.205000 | 4496.162000 | -2242.087000 | 0.550075 | 0.600000 | 0.700000 | HAZARD | POLY | 2.000000 | 0.000000 | 0.000000 | 99.033550 | 3.760158 | nan | 37.584680 | 0.100231 | 30.874110 | 45.753800 | 330.520400 | 37.584680 | 0.000000 | 0.100231 | 30.874110 | 45.753800 | 330.520400 | 902 | 0.100231 | 741 | 1098 | 330.520400 | 0.653611 | 0.640192 | 0.648279 | 0.583173 | 0.636554 | 0.672710 | 1 | 4 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 1 | 0 | 0 | 0 | 0 | 0 | 0 | 13

## Summary computation log

    This is mcds.exe version 6.2.0
     Options;
     Type=Point;
     Distance=Radial /Measure='Meter';
     Area /Units='Sq. Kilometer';
     Object=Single;
     SF=1;
     Selection=Sequential;
     Lookahead=1;
     Maxterms=5;
     Confidence=95;
     print=Selection;
     End;
     Data /Structure=Flat;
     Fields=STR_LABEL,STR_AREA,SMP_LABEL,SMP_EFFORT,DISTANCE;
     Infile=anlys\230430-153402\SylvAtri-ab-10mn-m-haz-pol-la-ra-ma-90vq_6nr\data.txt /NoEcho;
     Data will be input from file - [...]POL-LA-RA-MA-90VQ_6NR\DATA.TXT
     End;
     Dataset has been stored.
     Estimate;
     Distance /Left=4.55396 /Width=492.328;
     Density=All;
     Encounter=All;
     Detection=All;
     Size=All;
     Estimator /Key=HAZARD /Adjust=POLY /Criterion=AIC;
     Monotone=Strict;
     Pick=AIC;
     GOF /NClass=13;
     Cluster /Bias=GXLOG;
     VarN=Empirical;
     End;

## Detailed computation log

### Estimation Options Listing

     Parameter Estimation Specification
     ----------------------------------
     Encounter rate for all data combined
     Detection probability for all data combined
     Density for all data combined

     Distances:
     ----------
     Analysis based on exact distances
     Width specified as:    492.3280
     Left most value set at:    4.553960

     Estimators:
     -----------
     Estimator  1
     Key: Hazard Rate
     Adjustments - Function                 : Simple polynomials
                 - Term selection mode      : Sequential
                 - Term selection criterion : Akaike Information Criterion (AIC)
                 - Distances scaled by      : W (right truncation distance)

     Estimator selection: Choose estimator with minimum  AIC
     Estimation functions: constrained to be nearly monotone non-increasing

     Variances:
     ----------
     Variance of n: Empirical estimate from sample
                    (design-derived estimator R2/P2)
     Variance of f(0): MLE estimate

     Goodness of fit:
     ----------------
     Based on user defined cut points

     Glossary of terms
     -----------------

     Data items:
     n    - number of observed objects (single or clusters of animals)
     L    - total length of transect line(s)
     k    - number of samples
     K    - point transect effort, typically K=k
     T    - length of time searched in cue counting
     ER   - encounter rate (n/L or n/K or n/T)
     W    - width of line transect or radius of point transect
     x(i) - distance to i-th observation
     s(i) - cluster size of i-th observation
     r-p  - probability for regression test
     chi-p- probability for chi-square goodness-of-fit test

     Parameters or functions of parameters:
     m    - number of parameters in the model
     A(I) - i-th parameter in the estimated probability density function(pdf)
     f(0) - 1/u = value of pdf at zero for line transects
     u    - W*p = ESW, effective detection area for line transects
     h(0) - 2*PI/v
     v    - PI*W*W*p, is the effective detection area for point transects
     p    - probability of observing an object in defined area
     ESW  - for line transects, effective strip width = W*p
     EDR  - for point transects, effective detection radius  = W*sqrt(p)
     rho  - for cue counts, the cue rate
     DS   - estimate of density of clusters
     E(S) - estimate of expected value of cluster size
     D    - estimate of density of animals
     N    - estimate of number of animals in specified area

### Detection Fct/Global/Model Fitting

     Effort        :    190.0000
     # samples     :    96
     Width         :    492.3280
     Left          :    4.553960
     # observations:   401

     Model  1
        Hazard Rate key, k(y) = 1 - Exp(-(y/A(1))**-A(2))
           Results:
           Convergence was achieved with   19 function evaluations.
           Final Ln(likelihood) value =  -2242.0870
           Akaike information criterion =   4488.1743
           Bayesian information criterion =   4496.1621
           AICc =   4488.2046
           Final parameter values:   99.033556      3.7601583

     Model  2
        Hazard Rate key, k(y) = 1 - Exp(-(y/A(1))**-A(2))
        Simple polynomial adjustments of order(s) :  4
           Results:
           Convergence was achieved with   15 function evaluations.
           Final Ln(likelihood) value =  -2241.4494
           Akaike information criterion =   4488.8989
           Bayesian information criterion =   4500.8809
           AICc =   4488.9595
           Final parameter values:   99.547349      3.6794809    -0.56949598

        Likelihood ratio test between models  1 and  2
           Likelihood ratio test value    =     1.2753
           Probability of a greater value =   0.258774
     *** Model  1 selected over model  2 based on minimum AIC

### Detection Fct/Global/Parameter Estimates

     Effort        :    190.0000
     # samples     :    96
     Width         :    492.3280
     Left          :    4.553960
     # observations:   401

     Model
        Hazard Rate key, k(y) = 1 - Exp(-(y/A(1))**-A(2))

                  Point        Standard    Percent Coef.        95 Percent
      Parameter   Estimate       Error      of Variation     Confidence Interval
      ---------  -----------  -----------  --------------  ----------------------
        A( 1)      99.03        5.275
        A( 2)      3.760       0.2116
        h(0)     0.11189E-03  0.81687E-05       7.30      0.96951E-04  0.12914E-03
        p        0.73743E-01  0.53836E-02       7.30      0.63896E-01  0.85108E-01
        EDR       133.69       4.8802           3.65       124.44       143.64
      ---------  -----------  -----------  --------------  ----------------------

     Sampling Correlation of Estimated Parameters

             A( 1)   A( 2)
     A( 1)  1.000   0.762
     A( 2)  0.762   1.000

### Detection Fct/Global/Plot: Qq-plot

### Detection Fct/Global/K-S GOF Test

     Kolmogorov-Smirnov test
     -----------------------

     D_n                      = 0.0398                 p  = 0.5501

     Cramer-von Mises family tests
     -----------------------------

     W-sq (uniform weighting) = 0.1107          0.500 < p <= 0.600
       Relevant critical values:
         W-sq crit(alpha=0.600) = 0.0968
         W-sq crit(alpha=0.500) = 0.1187

     C-sq (cosine weighting)  = 0.0619          0.600 < p <= 0.700
       Relevant critical values:
         C-sq crit(alpha=0.700) = 0.0499
         C-sq crit(alpha=0.600) = 0.0622

### Detection Fct/Global/Plot: Detection Probability 1

### Detection Fct/Global/Plot: Pdf 1

### Detection Fct/Global/Chi-sq GOF Test 1

      Cell           Cut           Observed     Expected   Chi-square
       i            Points          Values       Values       Values
     -----------------------------------------------------------------
       1      4.55        42.1           42       39.25        0.192
       2      42.1        79.6           96      100.21        0.177
       3      79.6        117.          102      104.55        0.062
       4      117.        155.           61       61.01        0.000
       5      155.        192.           41       33.99        1.447
       6      192.        230.           22       20.35        0.134
       7      230.        267.           18       13.08        1.847
       8      267.        305.            6        8.91        0.952
       9      305.        342.            1        6.35        4.512
      10      342.        380.            6        4.70        0.361
      11      380.        417.            4        3.58        0.050
      12      417.        455.            0        2.79        2.791
      13      455.        492.            2        2.22        0.022
     -----------------------------------------------------------------
     Total Chi-square value =    12.5475  Degrees of Freedom = 10.00

    Probability of a greater chi-square value, P = 0.25008

     The program has limited capability for pooling.  The user should
     judge the necessity for pooling and if necessary, do pooling by hand.

### Density Estimates/Global

     Effort        :    190.0000
     # samples     :    96
     Width         :    492.3280
     Left          :    4.553960
     # observations:   401

     Model  1
        Hazard Rate key, k(y) = 1 - Exp(-(y/A(1))**-A(2))

                  Point        Standard    Percent Coef.        95% Percent
      Parameter   Estimate       Error      of Variation     Confidence Interval
      ---------  -----------  -----------  --------------  ----------------------
        D         37.585       3.7671          10.02       30.874       45.754
        N         902.00       90.408          10.02       741.00       1098.0
      ---------  -----------  -----------  --------------  ----------------------

     Measurement Units
     ---------------------------------
     Density: Numbers/Sq. kilometers
         EDR: meters

     Component Percentages of Var(D)
     -------------------------------
     Detection probability   :  53.1
     Encounter rate          :  46.9

### Estimation Summary - Encounter rates

                             Estimate      %CV     df     95% Confidence Interval
                            ------------------------------------------------------
                     n       401.00
                     k       96.000
                     K       190.00
                     n/K     2.1105        6.87    95.00  1.8418       2.4184
                     Left    4.5540
                     Width   492.33

### Estimation Summary - Detection probability

                             Estimate      %CV     df     95% Confidence Interval
                            ------------------------------------------------------
     Hazard/Polynomial
                     m       2.0000
                     LnL    -2242.1
                     AIC     4488.2
                     AICc    4488.2
                     BIC     4496.2
                     Chi-p  0.25008
                     h(0)   0.11189E-03    7.30   399.00 0.96951E-04  0.12914E-03
                     p      0.73743E-01    7.30   399.00 0.63896E-01  0.85108E-01
                     EDR     133.69        3.65   399.00  124.44       143.64

### Estimation Summary - Density&Abundance

                             Estimate      %CV     df     95% Confidence Interval
                            ------------------------------------------------------
     Hazard/Polynomial
                     D       37.585       10.02   330.52  30.874       45.754
                     N       902.00       10.02   330.52  741.00       1098.0

###### Generated on 30/04/2023 17:29:56 with Python 3, NumPy 1.23.2, Pandas, ZOOpt 0.4.0, Matplotlib, Jinja 2 ... and AutoDS , with icons from Font Awesome (sources : acdc-2019-nat-ds-params.py, ) .